import fileinput
import re
from datetime import datetime, timedelta

def parse(s):
    match = re.match(r'^(?P<int>\d+) \(.*\)$', s)
    if match:
        return parse(match.group('int'))
    try:
        return int(s)
    except:
        try:
            return datetime.strptime(s, '%c')
        except Exception as e:
            return s

tune2fs = {
        match.group('key'): parse(match.group('val'))
        for match in [
            re.match(r'^(?P<key>[^:]+):\s+(?P<val>.*)$', line)
            for line in fileinput.input()
        ]
        if match
}

try:
    # check mount count
    if tune2fs['Mount count'] >= tune2fs['Maximum mount count'] > 0:
        print("Mount count ({Mount count}) >= " 
              "Maximum mount count ({Maximum mount count})".format(**tune2fs))
        exit(1)
    # check fsck delay
    if tune2fs['Check interval'] and datetime.now() >= tune2fs['Last checked'] + timedelta(0, tune2fs['Check interval']):
        print("Fsck delay has been reached")
        exit(1)

except Exception as e:
    print(tune2fs)
    print(e)
    print('Internal error: contact your prefered devops')
    exit(3)

print('Mount count and Fsck delay are OK')
exit(0)
